<?php


namespace MirfalahTech\Laravel\Payment\Contracts;


interface PayableEntity
{
    /**
     * A unique id which represent the order.
     *
     * @return string
     */
    public function getBillId(): string;

    /**
     * Decimal number without any currency symbol, payment gateway need to convert
     * if different standard is used.
     *
     * @return string
     */
    public function getBillAmount(): string;

    /**
     * Get buyer's name.
     * @return string
     */
    public function getBillName(): string;

    /**
     * Get buyer's email.
     *
     * @return string
     */
    public function getBillEmail(): string;

    /**
     * Get buyer's phone number.
     *
     * @return string
     */
    public function getBillPhoneNumber(): string;

    /**
     * Get description for payment.
     *
     * @return string
     */
    public function getBillDescription(): string;

    /**
     * Get ISO 4214 currency code, payment gateway driver need to
     * convert if different standard is used.
     *
     * @return string
     */
    public function getBillCurrency(): string;

    /**
     * Get ISO 3166 country code, payment gateway driver need to
     * convert if different standard is used.
     *
     * @return string
     */
    public function getBillCountry(): string;
}